<?php

namespace Drupal\domain_route_access\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Routing\Access\AccessInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\domain\DomainNegotiatorInterface;

/**
 * Domain Route Access check.
 */
class DomainRouteAccessCheck implements AccessInterface {

  /**
   * Domain negotiator service.
   *
   * @var \Drupal\domain\DomainNegotiatorInterface
   */
  protected $domainNegotiator;

  /**
   * {@inheritDoc}
   */
  public function __construct(DomainNegotiatorInterface $domainNegotiator) {
    $this->domainNegotiator = $domainNegotiator;
  }

  /**
   * {@inheritDoc}
   */
  public function access(AccountInterface $account, $allowed_domain_ids) {
    $allowed_domain_ids = is_string($allowed_domain_ids) ? [$allowed_domain_ids] : $allowed_domain_ids;
    $allowed_domain_ids = is_array($allowed_domain_ids) ? $allowed_domain_ids : [];
    $current_domain = $this->domainNegotiator->getActiveId();
    return AccessResult::allowedIf(in_array($current_domain, $allowed_domain_ids, TRUE));
  }

}
