<?php

namespace Drupal\domain_route_access\Controller;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;

/**
 * Domain Route Access entity list builder.
 */
class DomainRouteAccessListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritDoc}
   */
  public function buildHeader() {
    $header = [
      'status' => $this->t('Active'),
      'label' => $this->t('Label'),
      'route_name' => $this->t('Route name'),
      'domains' => $this->t('Allowed domains'),
      'id' => $this->t('ID'),
    ];
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritDoc}
   */
  public function buildRow(EntityInterface $entity) {
    $row['status'] = $entity->isActive() ? '🟢' : '🔴';
    $row['label'] = $entity->label();
    $row['route_name'] = $entity->getRouteName();
    $row['domains'] = implode(', ', $entity->getDomains());
    $row['id'] = $entity->id();
    return $row + parent::buildRow($entity);
  }

  public function render()
  {
    $url = Url::fromRoute('domain_route_access.clear_cache')->toString(TRUE)->getGeneratedUrl();
    $html = "<div class='color-checked form-item__description'>";
    $html .= "🚨 Rebuild cache is required after Domain Route Access changes (Add, Update or Delete operations). ";
    $html .= "<a href='$url'>Clear Cache Now</a><br>";
    $html .= "We can flush the cache programmatically after each Domain Route Access change, but for performance reasons we recommend clearing the cache manually after you have completed all Domain Route Access changes.";
    $introduction = [
      '#markup' => $html
    ];
    return [
      $introduction,
      parent::render(),
    ];
  }

}
